--[[
path: /PetFeeder/
filename: PetFeeder_UnlikedFoodsFrame.lua
author: Jeff Parker <jeff3parker@gmail.com>
created: Tue, 22 Jan 2005 14:15:00 -0800
updated: Tue, 22 Jan 2005 21:39:00 -0800

Pet Feeder: a GUI interface allowing you configure happiness level for your pet & 
			drag/drop foods you wish your pet to eat.  When the pet happiness drops below
			the selected threshold will automatically feed your pet.
			To remove a food from the list, simply click on it.
]]

--[[
=============================================================================
Called when we want to display a list of foods
=============================================================================
]]
function PetFeeder_UnlikedFoodsFrame_OnReceiveDrag()
	
	local value = PetFeeder_GetItemObject(PetFeeder_PickedupItem.bag,PetFeeder_PickedupItem.slot);

	PetFeeder_DroptheItem( PetFeeder_BadFoods[PetFeeder_PetName], "any" );
	PetFeeder_RemoveFood(PetFeeder_Foods[PetFeeder_PetName], value.name);
	PetFeeder_UnlikedFoodsFrame_Update();
	PetFeeder_FoodsFrame_Update();	
end

--[[
=============================================================================
Called when we want to display a list of foods
=============================================================================
]]
function PetFeeder_UnlikedFoodsFrame_Update()
	local iItem;

	--updateQuantities();
	table.sort( PetFeeder_BadFoods[PetFeeder_PetName], function(a,b) return a.name < b.name end );
	--sortTheFoods(PetFeeder_BadFoods[PetFeeder_PetName]);

	local numEntries = table.getn(PetFeeder_BadFoods[PetFeeder_PetName] );
	
	FauxScrollFrame_Update(PetFeeder_UnlikedFoodsFrameListScrollFrame, numEntries, PETFEEDER_ITEMS_SHOWN, PETFEEDER_ITEM_HEIGHT, nil, nil, nil, nil, nil, PETFEEDER_ITEM_HEIGHT);
	
	local scrollFrameOffset = FauxScrollFrame_GetOffset(PetFeeder_UnlikedFoodsFrameListScrollFrame);

	for iItem = 1, PETFEEDER_ITEMS_SHOWN, 1 do
		
		local itemIndex = iItem + scrollFrameOffset;
		local buttonItem = getglobal("PetFeeder_UnlikedFoodsFrameItem"..iItem);
		if ( itemIndex > numEntries ) then
		  buttonItem:Hide();
		else
			iconTexture = getglobal("PetFeeder_UnlikedFoodsFrameItem"..iItem.."ItemIconTexture");
			local value = PetFeeder_BadFoods[PetFeeder_PetName][itemIndex];

			if ( value.texture ) then
				iconTexture:SetTexture( value.texture );
			end

 			local name = value.name; --.." ("..value.quantity..")";
 			--if ( value.quality ) then
 			--	name = name.." - quality: "..value.quality;
 			--end

			buttonItem:SetText(name);
			buttonItem:Show();
		end
	end	
end

--[[
=============================================================================
Called when Clear Foods button is clicked
=============================================================================
]]
function PetFeeder_UnlikedFoodsFrameClearFoodsButton_Update()
	PetFeeder_ClearBadFoods();
end

function PetFeeder_ClearBadFoods()
	if ( not PetFeeder_PetName or PetFeeder_PetName == "" ) then
		PetFeeder_PetName = UnitName( "pet" );
	end
	PetFeeder_BadFoods[PetFeeder_PetName] = {};
	PetFeeder_UnlikedFoodsFrame_Update();
end

--[[
=============================================================================
Called when the button item is clicked
=============================================================================
]]
function PetFeeder_UnlikedFoodsFrameItemButton_OnClick(button,name)
	if ( button == "LeftButton" ) then
		PetFeeder_RemoveFood( PetFeeder_BadFoods[PetFeeder_PetName], name );
		PetFeeder_UnlikedFoodsFrame_Update();
	end
end
